import { sendMessage } from '../utils/messaging';
import { createTask, assignTask, completeTask } from '../../services/taskService';

export function handleTaskCommand(body: string, sender: string, groupId: string, linkedGroups: Set<string>) {
  // Check if the message is from a group linked to the community
  if (groupId && linkedGroups.has(groupId)) { // Fixed: Added missing closing parenthesis
    // Parse the command
    if (body.startsWith('/tarea')) {
      // Remove the "/tarea" prefix and trim any extra spaces
      const command = body.replace('/tarea', '').trim();

      // Split the remaining command into action and arguments
      const [action, ...args] = command.split(' ');
      console.log('Parsed action:', action); // Log the action
      console.log('Parsed args:', args); // Log the arguments

      const description = args.join(' ');
      console.log('Description:', description); // Log the description

      // Extract assigned user (if any)
      const assignedUserMatch = description.match(/@\w+/);
      const assignedUser = assignedUserMatch ? assignedUserMatch[0] : null;

      // Extract due date (if any)
      const dueDateMatch = description.match(/\d{4}-\d{2}-\d{2}/);
      const dueDate = dueDateMatch ? dueDateMatch[0] : null;

      // Remove the assigned user and due date from the description
      const cleanDescription = description
        .replace(/@\w+/g, '') // Remove assigned user
        .replace(/\d{4}-\d{2}-\d{2}/g, '') // Remove due date
        .trim(); // Remove extra spaces

      if (action === 'nueva') {
        // If no user is assigned, default to the sender
        const finalAssignedUser = assignedUser || `@${sender.split('@')[0]}`;
        createTask(sender, cleanDescription, finalAssignedUser, dueDate);
      } else if (action === 'asignar') {
        const taskId = args[0];
        if (assignedUser) {
          assignTask(sender, taskId, assignedUser);
        } else {
          sendMessage(sender, 'Debes mencionar a un usuario para asignar la tarea. Ejemplo: /tarea asignar 1 @usuario');
        }
      } else if (action === 'completar') {
        const taskId = args[0];
        completeTask(sender, taskId);
      } else {
        sendMessage(sender, 'Acción no reconocida. Usa /tarea nueva, /tarea asignar, o /tarea completar.');
      }
    }
  }
}
