import { Task } from '../models/task';
import { sendMessage } from '../bot/utils/messaging';

// In-memory task storage
let tasks: Task[] = [];

// Create a new task
export function createTask(sender: string, description: string, assignedUser?: string, dueDate?: string) {
  const task: Task = {
    id: tasks.length + 1,
    description,
    assignedTo: assignedUser || null,
    dueDate: dueDate || null,
    completed: false,
  };
  tasks.push(task);
  sendMessage(sender, `Tarea creada: ${task.id} - ${task.description}${assignedUser ? ` asignada a ${assignedUser}` : ''}${dueDate ? ` para el ${dueDate}` : ''}`);
}

// Assign a task
export function assignTask(sender: string, taskId: string, assignedUser: string) {
  const task = tasks.find((t) => t.id === parseInt(taskId));
  if (task) {
    task.assignedTo = assignedUser;
    sendMessage(sender, `Tarea ${taskId} asignada a ${assignedUser}`);
  } else {
    sendMessage(sender, `Tarea ${taskId} no encontrada`);
  }
}

// Mark a task as completed
export function completeTask(sender: string, taskId: string) {
  const task = tasks.find((t) => t.id === parseInt(taskId));
  if (task) {
    task.completed = true;
    sendMessage(sender, `Tarea ${taskId} marcada como completada`);
  } else {
    sendMessage(sender, `Tarea ${taskId} no encontrada`);
  }
}

// Get all tasks (for debugging or future use)
export function getTasks(): Task[] {
  return tasks;
}
